==> tyrus-standalone-client-jdk-1.14-sources.jar: org/glassfish/tyrus/core/cluster/SessionEventListener.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2014-2016 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * http://glassfish.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package org.glassfish.tyrus.core.cluster;

import java.io.IOException;
import java.nio.ByteBuffer;

import javax.websocket.CloseReason;
import javax.websocket.Session;

/**
 * Session event listener.
 *
 * @author Pavel Bucek (pavel.bucek at oracle.com)
 */
public class SessionEventListener {

    private final Session session;

    /**
     * Constructor.
     *
     * @param session session to be used for sending messages passed from other nodes.
     */
    public SessionEventListener(Session session) {
        this.session = session;
    }

    /**
     * Invoked on send text message event.
     *
     * @param message message to be sent.
     * @throws IOException if there is a problem delivering the message.
     */
    public void onSendText(String message) throws IOException {
        session.getBasicRemote().sendText(message);
    }

    /**
     * Invoked on send partial text message event.
     *
     * @param message partial message to be sent.
     * @param isLast  {@code true} when the partial message being sent is the last part of the message.
     * @throws IOException if there is a problem delivering the message.
     */
    public void onSendText(String message, boolean isLast) throws IOException {
        session.getBasicRemote().sendText(message, isLast);
    }

    /**
     * Invoked on send binary message event.
     *
     * @param message data to be sent.
     * @throws IOException if there is a problem delivering the message.
     */
    public void onSendBinary(byte[] message) throws IOException {
        session.getBasicRemote().sendBinary(ByteBuffer.wrap(message));
    }

    /**
     * Invoked on send partial binary message event.
     *
     * @param message data to be sent.
     * @param isLast  {@code true} when the partial message being sent is the last part of the message.
     * @throws IOException if there is a problem delivering the message.
     */
    public void onSendBinary(byte[] message, boolean isLast) throws IOException {
        session.getBasicRemote().sendBinary(ByteBuffer.wrap(message), isLast);
    }

    /**
     * Invoked on send ping frame event.
     *
     * @param payload ping frame payload.
     * @throws IOException if there is a problem delivering the message.
     */
    public void onSendPing(byte[] payload) throws IOException {
        session.getBasicRemote().sendPing(ByteBuffer.wrap(payload));
    }

    /**
     * Invoked on send pong frame event.
     *
     * @param payload pong frame payload.
     * @throws IOException if there is a problem delivering the message.
     */
    public void onSendPong(byte[] payload) throws IOException {
        session.getBasicRemote().sendPong(ByteBuffer.wrap(payload));
    }

    /**
     * Invoked on session close event.
     *
     * @throws IOException if there is a problem closing the session.
     */
    public void onClose() throws IOException {
        session.close();
    }

    /**
     * Invoked on session close event.
     *
     * @param closeReason close reason of the session close event.
     * @throws IOException if there is a problem closing the session.
     */
    public void onClose(CloseReason closeReason) throws IOException {
        session.close(closeReason);
    }
}

==> tyrus-standalone-client-jdk-2.0.1-sources.jar: org/glassfish/tyrus/core/cluster/SessionEventListener.java <==
/*
 * Copyright (c) 2014, 2020 Oracle and/or its affiliates. All rights reserved.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0, which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the
 * Eclipse Public License v. 2.0 are satisfied: GNU General Public License,
 * version 2 with the GNU Classpath Exception, which is available at
 * https://www.gnu.org/software/classpath/license.html.
 *
 * SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
 */

package org.glassfish.tyrus.core.cluster;

import java.io.IOException;
import java.nio.ByteBuffer;

import jakarta.websocket.CloseReason;
import jakarta.websocket.Session;

/**
 * Session event listener.
 *
 * @author Pavel Bucek (pavel.bucek at oracle.com)
 */
public class SessionEventListener {

    private final Session session;

    /**
     * Constructor.
     *
     * @param session session to be used for sending messages passed from other nodes.
     */
    public SessionEventListener(Session session) {
        this.session = session;
    }

    /**
     * Invoked on send text message event.
     *
     * @param message message to be sent.
     * @throws IOException if there is a problem delivering the message.
     */
    public void onSendText(String message) throws IOException {
        session.getBasicRemote().sendText(message);
    }

    /**
     * Invoked on send partial text message event.
     *
     * @param message partial message to be sent.
     * @param isLast  {@code true} when the partial message being sent is the last part of the message.
     * @throws IOException if there is a problem delivering the message.
     */
    public void onSendText(String message, boolean isLast) throws IOException {
        session.getBasicRemote().sendText(message, isLast);
    }

    /**
     * Invoked on send binary message event.
     *
     * @param message data to be sent.
     * @throws IOException if there is a problem delivering the message.
     */
    public void onSendBinary(byte[] message) throws IOException {
        session.getBasicRemote().sendBinary(ByteBuffer.wrap(message));
    }

    /**
     * Invoked on send partial binary message event.
     *
     * @param message data to be sent.
     * @param isLast  {@code true} when the partial message being sent is the last part of the message.
     * @throws IOException if there is a problem delivering the message.
     */
    public void onSendBinary(byte[] message, boolean isLast) throws IOException {
        session.getBasicRemote().sendBinary(ByteBuffer.wrap(message), isLast);
    }

    /**
     * Invoked on send ping frame event.
     *
     * @param payload ping frame payload.
     * @throws IOException if there is a problem delivering the message.
     */
    public void onSendPing(byte[] payload) throws IOException {
        session.getBasicRemote().sendPing(ByteBuffer.wrap(payload));
    }

    /**
     * Invoked on send pong frame event.
     *
     * @param payload pong frame payload.
     * @throws IOException if there is a problem delivering the message.
     */
    public void onSendPong(byte[] payload) throws IOException {
        session.getBasicRemote().sendPong(ByteBuffer.wrap(payload));
    }

    /**
     * Invoked on session close event.
     *
     * @throws IOException if there is a problem closing the session.
     */
    public void onClose() throws IOException {
        session.close();
    }

    /**
     * Invoked on session close event.
     *
     * @param closeReason close reason of the session close event.
     * @throws IOException if there is a problem closing the session.
     */
    public void onClose(CloseReason closeReason) throws IOException {
        session.close(closeReason);
    }
}
